<?php

namespace FiloBlu\Rma\Plugin\Model;

/**
 * Class Rma
 * @package FiloBlu\Rma\Plugin\Model
 */
class Rma
{
    /**
     * @var string
     */
    const XML_PATH_RECEIVED_EMAIL_ENABLE = 'sales_email/magento_rma_receive/enabled';
    /**
     * @var \FiloBlu\Rma\Model\Rma\Status\HistoryFactory
     */
    protected $historyFactory;

    /**
     * @var \Psr\Log\LoggerInterface
     */
    protected $logger;
    /**
     * @var \Magento\Framework\App\Config\ScopeConfigInterface
     */
    protected $scopeConfig;

    /**
     * Rma constructor.
     * @param \FiloBlu\Rma\Model\Rma\Status\HistoryFactory $historyFactory
     * @param \Magento\Framework\App\Config\ScopeConfigInterface $scopeConfig
     * @param \Psr\Log\LoggerInterface $logger
     */
    public function __construct(\FiloBlu\Rma\Model\Rma\Status\HistoryFactory $historyFactory,
                                \Magento\Framework\App\Config\ScopeConfigInterface $scopeConfig,
                                \Psr\Log\LoggerInterface $logger)
    {
        $this->historyFactory = $historyFactory;
        $this->scopeConfig = $scopeConfig;
        $this->logger = $logger;
    }

    /**
     * @param \Magento\Rma\Model\Rma $subject
     * @param \Magento\Rma\Model\Rma|false $result
     * @return bool
     */
    public function afterSaveRma(\Magento\Rma\Model\Rma $subject, $result)
    {
        if ($result === false) {
            return $result;
        }

        try {

            $storeId = $subject->getStoreId();
            $enabled = boolval($this->getConfigValue(self::XML_PATH_RECEIVED_EMAIL_ENABLE, $storeId));

            if (!$enabled) {
                return $result;
            }

            $status = $result->getStatus();

            switch ($status) {
                case  \Magento\Rma\Model\Rma\Source\Status::STATE_RECEIVED:

                    /** @var $result \Magento\Rma\Model\Rma */
                    /** @var $statusHistory \FiloBlu\Rma\Model\Rma\Status\History */
                    $statusHistory = $this->historyFactory->create();
                    $statusHistory->setRmaEntityId($result->getEntityId());
                    $statusHistory->sendReceivedEmail();
                    break;
            }

        } catch (\Exception $e) {
            $this->logger->critical($e);
            return $result;
        }

        return $result;
    }

    /**
     * Return store configuration value
     *
     * @param string $path
     * @param int $storeId
     * @return mixed
     */
    protected function getConfigValue($path, $storeId)
    {
        return $this->scopeConfig->getValue(
            $path,
            \Magento\Store\Model\ScopeInterface::SCOPE_STORE,
            $storeId
        );
    }
}

